@@ -1,6 +1,6 @@
 import sys
 from whatap import DateUtil, conf
-from whatap.net.udp_session import UdpSession
+import whatap.net.async_sender as async_sender
 from whatap.pack import logSinkPack
 from whatap.trace.trace_context_manager import TraceContextManager
 import whatap.io as whatapio
